@@ -7,13 +7,9 @@
 #include "enum.h"
 #include "libkbolt_debug.h"
 
+#include <QList>
 #include <QStringList>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QStringRef>
-#else
 #include <QStringView>
-#endif
-#include <QVector>
 
 Bolt::Status Bolt::statusFromString(const QString &str)
 {
@@ -62,11 +58,7 @@ QString Bolt::statusToString(Bolt::Status status)
 
 Bolt::AuthFlags Bolt::authFlagsFromString(const QString &str)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const auto splitRef = str.splitRef(QStringLiteral("|"));
-#else
     const auto splitRef = str.split(QStringLiteral("|"));
-#endif
     Bolt::AuthFlags outFlags = Bolt::Auth::None;
     for (const auto &flag : splitRef) {
         const auto f = flag.trimmed();
@@ -223,3 +215,5 @@ Bolt::Security Bolt::securityFromString(const QString &str)
         return Bolt::Security::Unknown;
     }
 }
+
+#include "moc_enum.cpp"
